from django.conf.urls import url

from .views import ProfilerEntryJSON
from .views import ProfilerEntryView
from .views import ProfilerIndexView


urlpatterns = [
    url(r'^json/(?P<pk>[0-9]+)/?$', ProfilerEntryJSON.as_view(), name='ProfilerEntryJSON'),
    url(r'^view/?$',                ProfilerEntryView.as_view(), name='ProfilerEntryView'),
    url(r'^$',                      ProfilerIndexView.as_view(), name='ProfilerIndexView'),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-10-18 20:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_profiler_vmprof', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='requestprofile',
            name='allocated_vm',
            field=models.BigIntegerField(),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-10-17 00:26
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='RequestProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('started_at', models.DateTimeField()),
                ('created_at', models.DateTimeField()),
                ('request_path', models.TextField(blank=True)),
                ('response_code', models.IntegerField()),
                ('time_real', models.FloatField()),
                ('time_user', models.FloatField()),
                ('time_sys', models.FloatField()),
                ('allocated_vm', models.IntegerField()),
                ('data', models.BinaryField(null=True)),
                ('request_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from django.contrib.auth.models import User
from django.db.models import BigIntegerField
from django.db.models import BinaryField
from django.db.models import DateTimeField
from django.db.models import FloatField
from django.db.models import ForeignKey
from django.db.models import IntegerField
from django.db.models import TextField
from django.db.models import Model

class RequestProfile(Model):
    started_at = DateTimeField()
    created_at = DateTimeField()
    request_user = ForeignKey(User, null=True)
    request_path = TextField(blank=True)
    response_code = IntegerField()
    time_real = FloatField()
    time_user = FloatField()
    time_sys = FloatField()
    allocated_vm = BigIntegerField()
    data = BinaryField(null=True)
